abacusai.pipeline_version — AbacusAI documentation

# `abacusai.pipeline_version`

## Module Contents

### Classes

`PipelineVersion` | A version of a pipeline.

class abacusai.pipeline_version.PipelineVersion(client, pipelineName=None, pipelineId=None, pipelineVersion=None, createdAt=None, updatedAt=None, completedAt=None, status=None, error=None, pipelineVariableMappings=None, stepVersions={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of a pipeline.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - pipelineName (str) – The name of the pipeline this step is a part of.

    - pipelineId (str) – The reference to the pipeline this step belongs to.

    - pipelineVersion (str) – The reference to this pipeline version.

    - createdAt (str) – The date and time which this pipeline version was created.

    - updatedAt (str) – The date and time which this pipeline version was updated.

    - completedAt (str) – The date and time which this pipeline version was updated.

    - status (str) – The status of the pipeline version.

    - error (str) – The relevant error, if the status is FAILED.

    - pipelineVariableMappings (dict) – A description of the function variables into the pipeline.

    - stepVersions (PipelineStepVersion) – A list of the pipeline step versions.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      PipelineVersion

  describe()

    Describes a specified pipeline version

    Parameters:

      pipeline_version (str) – Unique string identifier for the pipeline version

    Returns:

      Object describing the pipeline version

    Return type:

      PipelineVersion

  wait_for_pipeline(timeout=1200)

    A waiting call until all the stages in a pipeline version have completed.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the pipeline version.

    Returns:

      A string describing the status of a pipeline version (pending, running, complete, etc.).

    Return type:

      str